@@ -1,4 +1,4 @@
-.FilterRegister = new.env()  # nolint
+.FilterRegister = new.env() # nolint
 
 #' Create a feature filter.
 #'
@@ -28,13 +28,14 @@
 #' @export
 #' @family filter
 makeFilter = function(name, desc, pkg, supported.tasks, supported.features, fun) {
+
   assertString(name)
   assertString(desc)
   assertCharacter(pkg, any.missing = FALSE)
   assertCharacter(supported.tasks, any.missing = FALSE)
   assertCharacter(supported.features, any.missing = FALSE)
   assertFunction(fun, c("task", "nselect"))
-  obj =  makeS3Obj("Filter",
+  obj = makeS3Obj("Filter",
     name = name,
     desc = desc,
     pkg = pkg,
@@ -66,6 +67,7 @@ makeFilter = function(name, desc, pkg, supported.tasks, supported.features, fun)
 #' @export
 #' @family filter
 listFilterMethods = function(desc = TRUE, tasks = FALSE, features = FALSE, include.deprecated = FALSE) {
+
   tag2df = function(tags, prefix = "") {
     unique.tags = sort(unique(unlist(tags)))
     res = asMatrixRows(lapply(tags, "%in%", x = unique.tags))
@@ -85,33 +87,39 @@ listFilterMethods = function(desc = TRUE, tasks = FALSE, features = FALSE, inclu
 
   description = extractSubList(filters, "desc")
 
-  if (desc)
+  if (desc) {
     df$desc = description
-  if (tasks)
+  }
+  if (tasks) {
     df = cbind(df, tag2df(extractSubList(filters, "supported.tasks"), prefix = "task."))
-  if (features)
+  }
+  if (features) {
     df = cbind(df, tag2df(extractSubList(filters, "supported.features"), prefix = "feature."))
+  }
   deprecated = stri_endswith(description, fixed = "(DEPRECATED)")
-  if (include.deprecated)
+  if (include.deprecated) {
     df$deprecated = deprecated
-  else
+  } else {
     df = df[!deprecated, ]
+  }
   res = setRowNames(sortByCol(df, "id"), NULL)
   addClasses(res, "FilterMethodsList")
 }
 
 #' @export
 print.FilterMethodsList = function(x, len = 40, ...) {
-  if (!is.null(x$desc))
+  if (!is.null(x$desc)) {
     x$desc = clipString(x$desc, len = len)
+  }
   NextMethod()
 }
 
 #' @export
 print.Filter = function(x, ...) {
   catf("Filter: '%s'", x$name)
-  if (!isScalarNA(x$pkg))
+  if (!isScalarNA(x$pkg)) {
     catf("Packages: '%s'", collapse(cleanupPackageNames(x$pkg)))
+  }
   catf("Supported tasks: %s", collapse(x$supported.tasks))
   catf("Supported features: %s", collapse(x$supported.features))
 }
@@ -130,10 +138,11 @@ NULL
 makeFilter(
   name = "mrmr",
   desc = "Minimum redundancy, maximum relevance filter",
-  pkg  = "mRMRe",
+  pkg = "mRMRe",
   supported.tasks = c("regr", "surv"),
   supported.features = c("numerics", "ordered"),
   fun = function(task, nselect, ...) {
+
     if (inherits(task, "SurvTask")) {
       data = getTaskData(task, target.extra = TRUE, recode.target = "surv")
       data = cbind(..surv = data$target, data$data)
@@ -154,8 +163,7 @@ makeFilter(
     res = mRMRe::mRMR.classic(data = data, target_indices = target.ind, feature_count = nselect, ...)
     scores = as.numeric(mRMRe::scores(res)[[1L]])
     setNames(scores, res@feature_names[as.integer(mRMRe::solutions(res)[[1L]])])
-  }
-)
+  })
 
 # carscore ----------------
 
@@ -170,15 +178,14 @@ NULL
 makeFilter(
   name = "carscore",
   desc = "CAR scores",
-  pkg  = "care",
+  pkg = "care",
   supported.tasks = "regr",
   supported.features = "numerics",
   fun = function(task, nselect, ...) {
     data = getTaskData(task, target.extra = TRUE)
     y = care::carscore(Xtrain = data$data, Ytrain = data$target, verbose = FALSE, ...)^2
     setNames(as.double(y), names(y))
-  }
-)
+  })
 
 # randomForestSRC_importance ----------------
 
@@ -199,11 +206,11 @@ NULL
 rf.importance = makeFilter(
   name = "randomForestSRC_importance",
   desc = "Importance of random forests fitted in package 'randomForestSRC'. Importance is calculated using argument 'permute'.",
-  pkg  = "randomForestSRC",
+  pkg = "randomForestSRC",
   supported.tasks = c("classif", "regr", "surv"),
   supported.features = c("numerics", "factors", "ordered"),
   fun = function(task, nselect, method = "permute", ...) {
-    assertChoice(method, choices = c("permute", "random", "anti", "permute.ensemble", "random.ensemble",  "anti.ensemble"))
+    assertChoice(method, choices = c("permute", "random", "anti", "permute.ensemble", "random.ensemble", "anti.ensemble"))
     im = randomForestSRC::rfsrc(getTaskFormula(task), data = getTaskData(task), proximity = FALSE,
       forest = FALSE, importance = method, ...)$importance
     if (inherits(task, "ClassifTask")) {
@@ -214,8 +221,7 @@ rf.importance = makeFilter(
       y = unname(im)
     }
     setNames(y, ns)
-  }
-)
+  })
 .FilterRegister[["rf.importance"]] = rf.importance
 .FilterRegister[["rf.importance"]]$desc = "(DEPRECATED)"
 .FilterRegister[["rf.importance"]]$fun = function(...) {
@@ -226,11 +232,11 @@ rf.importance = makeFilter(
 randomForestSRC.rfsrc = makeFilter(
   name = "randomForestSRC_importance",
   desc = "Importance of random forests fitted in package 'randomForestSRC'. Importance is calculated using argument 'permute'.",
-  pkg  = "randomForestSRC",
+  pkg = "randomForestSRC",
   supported.tasks = c("classif", "regr", "surv"),
   supported.features = c("numerics", "factors", "ordered"),
   fun = function(task, nselect, method = "permute", ...) {
-    assertChoice(method, choices = c("permute", "random", "anti", "permute.ensemble", "random.ensemble",  "anti.ensemble"))
+    assertChoice(method, choices = c("permute", "random", "anti", "permute.ensemble", "random.ensemble", "anti.ensemble"))
     im = randomForestSRC::rfsrc(getTaskFormula(task), data = getTaskData(task), proximity = FALSE,
       forest = FALSE, importance = method, ...)$importance
     if (inherits(task, "ClassifTask")) {
@@ -241,8 +247,7 @@ randomForestSRC.rfsrc = makeFilter(
       y = unname(im)
     }
     setNames(y, ns)
-  }
-)
+  })
 .FilterRegister[["randomForestSRC.rfsrc"]] = randomForestSRC.rfsrc
 .FilterRegister[["randomForestSRC.rfsrc"]]$desc = "(DEPRECATED)"
 .FilterRegister[["randomForestSRC.rfsrc"]]$fun = function(...) {
@@ -266,15 +271,14 @@ NULL
 rf.min.depth = makeFilter(
   name = "randomForestSRC_var.select",
   desc = "Minimal depth of / variable hunting via method var.select on random forests fitted in package 'randomForestSRC'.",
-  pkg  = "randomForestSRC",
+  pkg = "randomForestSRC",
   supported.tasks = c("classif", "regr", "surv"),
   supported.features = c("numerics", "factors", "ordered"),
   fun = function(task, nselect, method = "md", ...) {
     im = randomForestSRC::var.select(getTaskFormula(task), getTaskData(task),
       method = method, verbose = FALSE, ...)$md.obj$order
     setNames(-im[, 1L], rownames(im))
-  }
-)
+  })
 .FilterRegister[["rf.min.depth"]] = rf.min.depth
 .FilterRegister[["rf.min.depth"]]$desc = "(DEPRECATED)"
 .FilterRegister[["rf.min.depth"]]$fun = function(...) {
@@ -285,15 +289,14 @@ rf.min.depth = makeFilter(
 randomForestSRC.var.select = makeFilter(
   name = "randomForestSRC_var.select",
   desc = "Minimal depth of / variable hunting via method var.select on random forests fitted in package 'randomForestSRC'.",
-  pkg  = "randomForestSRC",
+  pkg = "randomForestSRC",
   supported.tasks = c("classif", "regr", "surv"),
   supported.features = c("numerics", "factors", "ordered"),
   fun = function(task, nselect, method = "md", ...) {
     im = randomForestSRC::var.select(getTaskFormula(task), getTaskData(task),
       method = method, verbose = FALSE, ...)$md.obj$order
     setNames(-im[, 1L], rownames(im))
-  }
-)
+  })
 .FilterRegister[["randomForestSRC.var.select"]] = randomForestSRC.var.select
 .FilterRegister[["randomForestSRC.var.select"]]$desc = "(DEPRECATED)"
 .FilterRegister[["randomForestSRC.var.select"]]$fun = function(...) {
@@ -319,39 +322,14 @@ makeFilter(
   supported.tasks = c("classif", "regr", "surv"),
   supported.features = c("numerics", "factors", "ordered"),
   fun = function(task, nselect, mtry = 5L, ...) {
-    args = list(...)
-    # we need to set mtry, which is 5 by default in cforest, to p if p < mtry
-    # otherwise we get a warning
-    p = getTaskNFeats(task)
-    if (p < mtry)
-      args$mtry = p
-    cforest.args = as.list(base::args(party::cforest))
-    cforest.args = args[names(args) %in% names(cforest.args)]
-    control.args = as.list(base::args(party::cforest_control))
-    control.args = args[names(args) %in% names(control.args)]
-    varimp.args = as.list(base::args(party::varimp))
-    varimp.args = args[names(args) %in% names(varimp.args)]
-    ctrl = do.call(party::cforest_unbiased, control.args)
-    fit = do.call(party::cforest, c(list(formula = getTaskFormula(task), data = getTaskData(task), controls = ctrl),
-                                    cforest.args))
-    im = do.call(party::varimp, c(list(obj = fit), varimp.args))
-    im
-  }
-)
 
-cforest.importance = makeFilter(
-  name = "party_cforest.importance",
-  desc = "Permutation importance of random forest fitted in package 'party'",
-  pkg = "party",
-  supported.tasks = c("classif", "regr", "surv"),
-  supported.features = c("numerics", "factors", "ordered"),
-  fun = function(task, nselect, mtry = 5L, ...) {
     args = list(...)
     # we need to set mtry, which is 5 by default in cforest, to p if p < mtry
     # otherwise we get a warning
     p = getTaskNFeats(task)
-    if (p < mtry)
+    if (p < mtry) {
       args$mtry = p
+    }
     cforest.args = as.list(base::args(party::cforest))
     cforest.args = args[names(args) %in% names(cforest.args)]
     control.args = as.list(base::args(party::cforest_control))
@@ -363,8 +341,35 @@ cforest.importance = makeFilter(
       cforest.args))
     im = do.call(party::varimp, c(list(obj = fit), varimp.args))
     im
-  }
-)
+  })
+
+cforest.importance = makeFilter(
+  name = "party_cforest.importance",
+  desc = "Permutation importance of random forest fitted in package 'party'",
+  pkg = "party",
+  supported.tasks = c("classif", "regr", "surv"),
+  supported.features = c("numerics", "factors", "ordered"),
+  fun = function(task, nselect, mtry = 5L, ...) {
+
+    args = list(...)
+    # we need to set mtry, which is 5 by default in cforest, to p if p < mtry
+    # otherwise we get a warning
+    p = getTaskNFeats(task)
+    if (p < mtry) {
+      args$mtry = p
+    }
+    cforest.args = as.list(base::args(party::cforest))
+    cforest.args = args[names(args) %in% names(cforest.args)]
+    control.args = as.list(base::args(party::cforest_control))
+    control.args = args[names(args) %in% names(control.args)]
+    varimp.args = as.list(base::args(party::varimp))
+    varimp.args = args[names(args) %in% names(varimp.args)]
+    ctrl = do.call(party::cforest_unbiased, control.args)
+    fit = do.call(party::cforest, c(list(formula = getTaskFormula(task), data = getTaskData(task), controls = ctrl),
+      cforest.args))
+    im = do.call(party::varimp, c(list(obj = fit), varimp.args))
+    im
+  })
 
 .FilterRegister[["cforest.importance"]] = cforest.importance
 .FilterRegister[["cforest.importance"]]$desc = "(DEPRECATED)"
@@ -401,8 +406,7 @@ makeFilter(
       keep.forest = FALSE, importance = (type != 2L))
     im = randomForest::importance(rf, type = type, ...)
     setNames(im, rownames(im))
-  }
-)
+  })
 
 randomForest.importance = makeFilter(
   name = "randomForest_importance",
@@ -418,8 +422,7 @@ randomForest.importance = makeFilter(
       keep.forest = FALSE, importance = (type != 2L))
     im = randomForest::importance(rf, type = type, ...)
     setNames(im, rownames(im))
-  }
-)
+  })
 
 .FilterRegister[["randomForest.importance"]] = randomForest.importance
 .FilterRegister[["randomForest.importance"]]$desc = "(DEPRECATED)"
@@ -440,14 +443,13 @@ NULL
 makeFilter(
   name = "linear.correlation",
   desc = "Pearson correlation between feature and target",
-  pkg  = character(0L),
+  pkg = character(0L),
   supported.tasks = "regr",
   supported.features = "numerics",
   fun = function(task, nselect, ...) {
     data = getTaskData(task, target.extra = TRUE)
     abs(cor(as.matrix(data$data), data$target, use = "pairwise.complete.obs", method = "pearson")[, 1L])
-  }
-)
+  })
 
 # rank.correlation ----------------
 
@@ -461,14 +463,13 @@ NULL
 makeFilter(
   name = "rank.correlation",
   desc = "Spearman's correlation between feature and target",
-  pkg  = character(0L),
+  pkg = character(0L),
   supported.tasks = "regr",
   supported.features = "numerics",
   fun = function(task, nselect, ...) {
     data = getTaskData(task, target.extra = TRUE)
     abs(cor(as.matrix(data$data), data$target, use = "pairwise.complete.obs", method = "spearman")[, 1L])
-  }
-)
+  })
 
 # FSelector_information.gain ----------------
 
@@ -480,26 +481,24 @@ makeFilter(
 makeFilter(
   name = "FSelector_information.gain",
   desc = "Entropy-based information gain between feature and target",
-  pkg  = "FSelector",
+  pkg = "FSelector",
   supported.tasks = c("classif", "regr"),
   supported.features = c("numerics", "factors"),
   fun = function(task, nselect, ...) {
     y = FSelector::information.gain(getTaskFormula(task), data = getTaskData(task))
     setNames(y[["attr_importance"]], getTaskFeatureNames(task))
-  }
-)
+  })
 
 information.gain = makeFilter(
   name = "FSelector_information.gain",
   desc = "Entropy-based information gain between feature and target",
-  pkg  = "FSelector",
+  pkg = "FSelector",
   supported.tasks = c("classif", "regr"),
   supported.features = c("numerics", "factors"),
   fun = function(task, nselect, ...) {
     y = FSelector::information.gain(getTaskFormula(task), data = getTaskData(task))
     setNames(y[["attr_importance"]], getTaskFeatureNames(task))
-  }
-)
+  })
 
 .FilterRegister[["information.gain"]] = information.gain
 .FilterRegister[["information.gain"]]$desc = "(DEPRECATED)"
@@ -519,26 +518,24 @@ information.gain = makeFilter(
 makeFilter(
   name = "FSelector_gain.ratio",
   desc = "Entropy-based gain ratio between feature and target",
-  pkg  = "FSelector",
+  pkg = "FSelector",
   supported.tasks = c("classif", "regr"),
   supported.features = c("numerics", "factors"),
   fun = function(task, nselect, ...) {
     y = FSelector::gain.ratio(getTaskFormula(task), data = getTaskData(task))
     setNames(y[["attr_importance"]], getTaskFeatureNames(task))
-  }
-)
+  })
 
 gain.ratio = makeFilter(
   name = "FSelector_gain.ratio",
   desc = "Entropy-based gain ratio between feature and target",
-  pkg  = "FSelector",
+  pkg = "FSelector",
   supported.tasks = c("classif", "regr"),
   supported.features = c("numerics", "factors"),
   fun = function(task, nselect, ...) {
     y = FSelector::gain.ratio(getTaskFormula(task), data = getTaskData(task))
     setNames(y[["attr_importance"]], getTaskFeatureNames(task))
-  }
-)
+  })
 
 .FilterRegister[["gain.ratio"]] = gain.ratio
 .FilterRegister[["gain.ratio"]]$desc = "(DEPRECATED)"
@@ -557,26 +554,24 @@ gain.ratio = makeFilter(
 makeFilter(
   name = "FSelector_symmetrical.uncertainty",
   desc = "Entropy-based symmetrical uncertainty between feature and target",
-  pkg  = "FSelector",
+  pkg = "FSelector",
   supported.tasks = c("classif", "regr"),
   supported.features = c("numerics", "factors"),
   fun = function(task, nselect, ...) {
     y = FSelector::symmetrical.uncertainty(getTaskFormula(task), data = getTaskData(task))
     setNames(y[["attr_importance"]], getTaskFeatureNames(task))
-  }
-)
+  })
 
 symmetrical.uncertainty = makeFilter(
   name = "FSelector_symmetrical.uncertainty",
   desc = "Entropy-based symmetrical uncertainty between feature and target",
-  pkg  = "FSelector",
+  pkg = "FSelector",
   supported.tasks = c("classif", "regr"),
   supported.features = c("numerics", "factors"),
   fun = function(task, nselect, ...) {
     y = FSelector::symmetrical.uncertainty(getTaskFormula(task), data = getTaskData(task))
     setNames(y[["attr_importance"]], getTaskFeatureNames(task))
-  }
-)
+  })
 
 .FilterRegister[["symmetrical.uncertainty"]] = symmetrical.uncertainty
 .FilterRegister[["symmetrical.uncertainty"]]$desc = "(DEPRECATED)"
@@ -601,26 +596,24 @@ NULL
 makeFilter(
   name = "FSelector_chi.squared",
   desc = "Chi-squared statistic of independence between feature and target",
-  pkg  = "FSelector",
+  pkg = "FSelector",
   supported.tasks = c("classif", "regr"),
   supported.features = c("numerics", "factors"),
   fun = function(task, nselect, ...) {
     y = FSelector::chi.squared(getTaskFormula(task), data = getTaskData(task))
     setNames(y[["attr_importance"]], getTaskFeatureNames(task))
-  }
-)
+  })
 
 chi.squared = makeFilter(
   name = "FSelector_gain.ratio",
   desc = "Chi-squared statistic of independence between feature and target",
-  pkg  = "FSelector",
+  pkg = "FSelector",
   supported.tasks = c("classif", "regr"),
   supported.features = c("numerics", "factors"),
   fun = function(task, nselect, ...) {
     y = FSelector::chi.squared(getTaskFormula(task), data = getTaskData(task))
     setNames(y[["attr_importance"]], getTaskFeatureNames(task))
-  }
-)
+  })
 
 .FilterRegister[["chi.squared"]] = chi.squared
 .FilterRegister[["chi.squared"]]$desc = "(DEPRECATED)"
@@ -652,26 +645,24 @@ NULL
 makeFilter(
   name = "FSelector_relief",
   desc = "RELIEF algorithm",
-  pkg  = "FSelector",
+  pkg = "FSelector",
   supported.tasks = c("classif", "regr"),
   supported.features = c("numerics", "factors"),
   fun = function(task, nselect, ...) {
     y = FSelector::relief(getTaskFormula(task), data = getTaskData(task), ...)
     setNames(y[["attr_importance"]], getTaskFeatureNames(task))
-  }
-)
+  })
 
 relief = makeFilter(
   name = "FSelector_relief",
   desc = "RELIEF algorithm",
-  pkg  = "FSelector",
+  pkg = "FSelector",
   supported.tasks = c("classif", "regr"),
   supported.features = c("numerics", "factors"),
   fun = function(task, nselect, ...) {
     y = FSelector::relief(getTaskFormula(task), data = getTaskData(task), ...)
     setNames(y[["attr_importance"]], getTaskFeatureNames(task))
-  }
-)
+  })
 
 .FilterRegister[["relief"]] = relief
 .FilterRegister[["relief"]]$desc = "(DEPRECATED)"
@@ -695,26 +686,24 @@ NULL
 makeFilter(
   name = "FSelector_oneR",
   desc = "oneR association rule",
-  pkg  = "FSelector",
+  pkg = "FSelector",
   supported.tasks = c("classif", "regr"),
   supported.features = c("numerics", "factors"),
   fun = function(task, nselect, ...) {
     y = FSelector::oneR(getTaskFormula(task), data = getTaskData(task))
     setNames(y[["attr_importance"]], getTaskFeatureNames(task))
-  }
-)
+  })
 
 oneR = makeFilter(
   name = "FSelector_oneR",
   desc = "oneR association rule",
-  pkg  = "FSelector",
+  pkg = "FSelector",
   supported.tasks = c("classif", "regr"),
   supported.features = c("numerics", "factors"),
   fun = function(task, nselect, ...) {
     y = FSelector::oneR(getTaskFormula(task), data = getTaskData(task))
     setNames(y[["attr_importance"]], getTaskFeatureNames(task))
-  }
-)
+  })
 
 .FilterRegister[["oneR"]] = oneR
 .FilterRegister[["oneR"]]$desc = "(DEPRECATED)"
@@ -738,30 +727,35 @@ NULL
 univariate = makeFilter(
   name = "univariate.model.score",
   desc = "Resamples an mlr learner for each input feature individually. The resampling performance is used as filter score, with rpart as default learner.",
-  pkg  = character(0L),
+  pkg = character(0L),
   supported.tasks = c("classif", "regr", "surv"),
   supported.features = c("numerics", "factors", "ordered"),
   fun = function(task, nselect, perf.learner = NULL, perf.measure = NULL, perf.resampling = NULL, ...) {
+
     typ = getTaskType(task)
     if (is.null(perf.learner)) {
-      if (typ == "classif")
+      if (typ == "classif") {
         perf.learner = "classif.rpart"
-      else if (typ == "regr")
+      } else if (typ == "regr") {
         perf.learner = "regr.rpart"
-      else if (typ == "surv")
+      } else if (typ == "surv") {
         perf.learner = "surv.rpart"
+      }
     }
     if (is.null(perf.measure)) {
       perf.measure = getDefaultMeasure(task)
     }
     perf.learner = checkLearner(perf.learner)
     perf.measure = checkMeasures(perf.measure, perf.learner)
-    if (length(perf.measure) != 1L)
+    if (length(perf.measure) != 1L) {
       stop("Exactly one measure must be provided")
-    if (is.null(perf.resampling))
+    }
+    if (is.null(perf.resampling)) {
       perf.resampling = makeResampleDesc("Subsample", iters = 1L, split = 0.67)
-    if (getTaskType(task) != perf.learner$type)
+    }
+    if (getTaskType(task) != perf.learner$type) {
       stopf("Expected task of type '%s', not '%s'", getTaskType(task), perf.learner$type)
+    }
 
     fns = getTaskFeatureNames(task)
     res = double(length(fns))
@@ -769,11 +763,11 @@ univariate = makeFilter(
       subtask = subsetTask(task, features = fns[i])
       res[i] = resample(learner = perf.learner, task = subtask, resampling = perf.resampling, measures = perf.measure, keep.pred = FALSE, show.info = FALSE)$aggr
     }
-    if (perf.measure[[1L]]$minimize)
+    if (perf.measure[[1L]]$minimize) {
       res = -1.0 * res
+    }
     setNames(res, fns)
-  }
-)
+  })
 .FilterRegister[["univariate"]] = univariate
 .FilterRegister[["univariate"]]$desc = "(DEPRECATED)"
 .FilterRegister[["univariate"]]$fun = function(...) {
@@ -804,8 +798,7 @@ makeFilter(
       aov.t = aov(f, data = data)
       summary(aov.t)[[1L]][1L, "F value"]
     })
-  }
-)
+  })
 
 # kruskal.test ----------------
 
@@ -833,8 +826,7 @@ makeFilter(
       t = kruskal.test(f, data = data)
       unname(t$statistic)
     })
-  }
-)
+  })
 
 # variance ----------------
 
@@ -857,8 +849,7 @@ makeFilter(
     sapply(getTaskFeatureNames(task), function(feat.name) {
       var(data[[feat.name]], na.rm = na.rm)
     })
-  }
-)
+  })
 
 # permutation.importance ----------------
 
@@ -882,7 +873,7 @@ makeFilter(
   supported.tasks = c("classif", "regr", "surv"),
   supported.features = c("numerics", "factors", "ordered"),
   fun = function(task, imp.learner, measure, contrast = function(x, y) x - y,
-                 aggregation = mean, nmc = 50L, replace = FALSE, nselect) {
+    aggregation = mean, nmc = 50L, replace = FALSE, nselect) {
     imp = generateFeatureImportanceData(task, "permutation.importance",
       imp.learner, interaction = FALSE, measure = measure,
       contrast = contrast, aggregation = aggregation,
@@ -890,8 +881,7 @@ makeFilter(
     imp = as.numeric(imp$res)
     names(imp) = getTaskFeatureNames(task)
     return(imp)
-  }
-)
+  })
 
 # auc ----------------
 
@@ -908,7 +898,7 @@ NULL
 makeFilter(
   name = "auc",
   desc = "AUC filter for binary classification tasks",
-  pkg  = character(0L),
+  pkg = character(0L),
   supported.tasks = "classif",
   supported.features = "numerics",
   fun = function(task, nselect, ...) {
@@ -917,8 +907,7 @@ makeFilter(
       measureAUC(x, y, task$task.desc$negative, task$task.desc$positive)
     }, y = data$target)
     abs(0.5 - score)
-  }
-)
+  })
 
 #' Filters from the package \pkg{praznik} use the mutual information criteria in a greedy forward fashion:
 #' \dQuote{praznik_CMIM}, \dQuote{praznik_DISR}, \dQuote{praznik_JMIM}, \dQuote{praznik_JMI},
@@ -934,6 +923,7 @@ praznik_filter = function(fun) {
   force(fun)
 
   function(task, nselect, ...) {
+
     fun = getFromNamespace(fun, ns = "praznik")
 
     data = getTaskData(task)
@@ -1013,7 +1003,7 @@ makeFilter(
   name = "praznik_MRMR",
   desc = "Minimum redundancy maximal relevancy filter",
   pkg = "praznik",
-  supported.tasks = "classif",
+  supported.tasks = c("classif", "regr", "surv"),
   supported.features = c("numerics", "factors", "integer", "character", "logical"),
   fun = praznik_filter("MRMR")
 )
@@ -1030,7 +1020,7 @@ makeFilter(
 )
 
 #' Entropy based filters from the package \pkg{FSelectorRcpp}:
-#' \dQuote{FSelectorRcpp_gainratio}, dQuote{FSelectorRcpp_infogain}, \dQuote{FSelectorRcpp_symuncert}.
+#' \dQuote{FSelectorRcpp_gain.ratio}, dQuote{FSelectorRcpp_information.gain}, \dQuote{FSelectorRcpp_symmetrical.uncertainty}.
 #' @rdname makeFilter
 #' @name makeFilter
 NULL
@@ -1042,7 +1032,7 @@ FSelectorRcpp.filter = function(type) {
     data = getTaskData(task)
     X = data[getTaskFeatureNames(task)]
     y = data[[getTaskTargetNames(task)]]
-    res = FSelectorRcpp::information_gain(x = X, y = y, type = type, equal = FALSE)
+    res = FSelectorRcpp::information_gain(x = X, y = y, type = type, ...)
     res = setNames(res$importance, res$attributes)
     replace(res, is.nan(res), 0) # FIXME: this is a technical fix, need to report upstream
   }
@@ -1053,7 +1043,7 @@ FSelectorRcpp.filter = function(type) {
 makeFilter(
   name = "FSelectorRcpp_information.gain",
   desc = "Entropy-based Filters: Algorithms that find ranks of importance of discrete attributes, basing on their entropy with a continous class attribute",
-  pkg  = "FSelectorRcpp",
+  pkg = "FSelectorRcpp",
   supported.tasks = c("classif", "regr"),
   supported.features = c("numerics", "factors", "integer", "logical", "character"),
   fun = FSelectorRcpp.filter("infogain")
@@ -1064,7 +1054,7 @@ makeFilter(
 makeFilter(
   name = "FSelectorRcpp_gain.ratio",
   desc = "Entropy-based Filters: Algorithms that find ranks of importance of discrete attributes, basing on their entropy with a continous class attribute",
-  pkg  = "FSelectorRcpp",
+  pkg = "FSelectorRcpp",
   supported.tasks = c("classif", "regr"),
   supported.features = c("numerics", "factors", "integer", "logical", "character"),
   fun = FSelectorRcpp.filter("gainratio")
@@ -1075,7 +1065,7 @@ makeFilter(
 makeFilter(
   name = "FSelectorRcpp_symmetrical.uncertainty",
   desc = "Entropy-based Filters: Algorithms that find ranks of importance of discrete attributes, basing on their entropy with a continous class attribute",
-  pkg  = "FSelectorRcpp",
+  pkg = "FSelectorRcpp",
   supported.tasks = c("classif", "regr"),
   supported.features = c("numerics", "factors", "integer", "logical", "character"),
   fun = FSelectorRcpp.filter("symuncert")
@@ -1094,7 +1084,7 @@ NULL
 makeFilter(
   name = "ranger_permutation",
   desc = "Variable importance based on ranger permutation importance",
-  pkg  = "ranger",
+  pkg = "ranger",
   supported.tasks = c("classif", "regr", "surv"),
   supported.features = c("numerics", "factors", "ordered"),
   fun = function(task, nselect, ...) {
@@ -1102,13 +1092,12 @@ makeFilter(
     lrn = makeLearner(lrn.type, importance = "permutation", ...)
     mod = train(lrn, task)
     ranger::importance(mod$learner.model)
-  }
-)
+  })
 
 ranger.permutation = makeFilter(
   name = "ranger_permutation",
   desc = "Variable importance based on ranger permutation importance",
-  pkg  = "ranger",
+  pkg = "ranger",
   supported.tasks = c("classif", "regr", "surv"),
   supported.features = c("numerics", "factors", "ordered"),
   fun = function(task, nselect, ...) {
@@ -1116,8 +1105,7 @@ ranger.permutation = makeFilter(
     lrn = makeLearner(lrn.type, importance = "permutation", ...)
     mod = train(lrn, task)
     ranger::importance(mod$learner.model)
-  }
-)
+  })
 
 .FilterRegister[["ranger.permutation"]] = ranger.permutation
 .FilterRegister[["ranger.permutation"]]$desc = "(DEPRECATED)"
@@ -1139,7 +1127,7 @@ NULL
 makeFilter(
   name = "ranger_impurity",
   desc = "Variable importance based on ranger impurity importance",
-  pkg  = "ranger",
+  pkg = "ranger",
   supported.tasks = c("classif", "regr"),
   supported.features = c("numerics", "factors", "ordered"),
   fun = function(task, nselect, ...) {
@@ -1147,13 +1135,12 @@ makeFilter(
     lrn = makeLearner(lrn.type, importance = "impurity", ...)
     mod = train(lrn, task)
     ranger::importance(mod$learner.model)
-  }
-)
+  })
 
 ranger.impurity = makeFilter(
   name = "ranger_impurity",
   desc = "Variable importance based on ranger impurity importance",
-  pkg  = "ranger",
+  pkg = "ranger",
   supported.tasks = c("classif", "regr"),
   supported.features = c("numerics", "factors", "ordered"),
   fun = function(task, nselect, ...) {
@@ -1161,8 +1148,7 @@ ranger.impurity = makeFilter(
     lrn = makeLearner(lrn.type, importance = "impurity", ...)
     mod = train(lrn, task)
     ranger::importance(mod$learner.model)
-  }
-)
+  })
 
 
 .FilterRegister[["ranger.impurity"]] = ranger.impurity
