@@ -6,7 +6,7 @@ makeRLearner.classif.h2o.gbm = function() {
     par.set = makeParamSet(
       makeIntegerLearnerParam("ntrees", lower = 1L, default = 50L),
       makeIntegerLearnerParam("max_depth", lower = 1L, default = 5L),
-      makeIntegerLearnerParam("min_rows", lower = 1L,  default = 10L),
+      makeIntegerLearnerParam("min_rows", lower = 1L, default = 10L),
       makeNumericLearnerParam("learn_rate", lower = 0, upper = 1, default = 0.1),
       makeIntegerLearnerParam("nbins", lower = 1L, default = 20L),
       makeIntegerLearnerParam("nbins_cats", lower = 1L, default = 1024L),
@@ -14,7 +14,7 @@ makeRLearner.classif.h2o.gbm = function() {
       makeIntegerLearnerParam("max_after_balance_size", lower = 0L, default = 1L),
       makeIntegerLearnerParam("seed", tunable = FALSE)
     ),
-    properties = c("twoclass", "multiclass", "numerics", "factors", "prob", "missings"),
+    properties = c("twoclass", "multiclass", "numerics", "factors", "prob", "missings", "featimp"),
     name = "h2o.gbm",
     short.name = "h2o.gbm",
     note = "'distribution' is set automatically to 'gaussian'.",
@@ -23,7 +23,8 @@ makeRLearner.classif.h2o.gbm = function() {
 }
 
 #' @export
-trainLearner.classif.h2o.gbm = function(.learner, .task, .subset, .weights = NULL,  ...) {
+trainLearner.classif.h2o.gbm = function(.learner, .task, .subset, .weights = NULL, ...) {
+
   # check if h2o connection already exists, otherwise start one
   conn.up = tryCatch(h2o::h2o.getConnection(), error = function(err) return(FALSE))
   if (!inherits(conn.up, "H2OConnection")) {
@@ -39,6 +40,7 @@ trainLearner.classif.h2o.gbm = function(.learner, .task, .subset, .weights = NUL
 
 #' @export
 predictLearner.classif.h2o.gbm = function(.learner, .model, .newdata, ...) {
+
   m = .model$learner.model
   h2of = h2o::as.h2o(.newdata)
   p = h2o::h2o.predict(m, newdata = h2of, ...)
@@ -47,8 +49,9 @@ predictLearner.classif.h2o.gbm = function(.learner, .model, .newdata, ...) {
   # check if class names are integers. if yes, colnames of p.df need to be adapted
   int = stri_detect_regex(p.df$predict, "^[[:digit:]]+$")
   pcol = stri_detect_regex(colnames(p.df), "^p[[:digit:]]+$")
-  if (any(int) && any(pcol))
+  if (any(int) && any(pcol)) {
     colnames(p.df)[pcol] = stri_sub(colnames(p.df)[pcol], 2L)
+  }
 
   if (.learner$predict.type == "response") {
     return(p.df$predict)
@@ -57,3 +60,9 @@ predictLearner.classif.h2o.gbm = function(.learner, .model, .newdata, ...) {
     return(as.matrix(p.df))
   }
 }
+
+#' @export
+getFeatureImportanceLearner.classif.h2o.gbm = function(.learner, .model, ...) {
+  mod = getLearnerModel(.model, more.unwrap = TRUE)
+  extractH2OVarImp(mod, ...)
+}
