@@ -5,7 +5,7 @@ makeRLearner.classif.kknn = function() {
     # FIXME: kknn set its own contr.dummy function, if we requireNamespace,
     # this is not found, see issue  226
     package = "!kknn",
-    #FIXME: find out what ykernel and contrasts really do
+    # FIXME: find out what ykernel and contrasts really do
     par.set = makeParamSet(
       makeIntegerLearnerParam(id = "k", default = 7L, lower = 1L),
       makeNumericLearnerParam(id = "distance", default = 2, lower = 0),
@@ -22,7 +22,7 @@ makeRLearner.classif.kknn = function() {
 }
 
 #' @export
-trainLearner.classif.kknn = function(.learner, .task, .subset, .weights = NULL,  ...) {
+trainLearner.classif.kknn = function(.learner, .task, .subset, .weights = NULL, ...) {
   list(td = getTaskDesc(.task), data = getTaskData(.task, .subset), parset = list(...))
 }
 
@@ -33,9 +33,9 @@ predictLearner.classif.kknn = function(.learner, .model, .newdata, ...) {
   pars = list(formula = f, train = m$data, test = .newdata)
   pars = c(pars, m$parset, list(...))
   m = do.call(kknn::kknn, pars)
-  if (.learner$predict.type == "response")
+  if (.learner$predict.type == "response") {
     return(m$fitted.values)
-  else
+  } else {
     return(m$prob)
+  }
 }
-
