@@ -6,9 +6,9 @@ makeRLearner.classif.plsdaCaret = function() {
       makeIntegerLearnerParam(id = "ncomp", default = 2, lower = 1),
       makeDiscreteLearnerParam(id = "probMethod", values = c("softmax", "Bayes"), default = "softmax"),
       makeDiscreteLearnerParam(id = "method", default = "kernelpls",
-                               values = c("kernelpls", "widekernelpls", "simpls", "oscorespls"))
+        values = c("kernelpls", "widekernelpls", "simpls", "oscorespls"))
     ),
-    properties = c("numerics", "prob", "twoclass"),
+    properties = c("numerics", "prob", "twoclass", "multiclass"),
     name = "Partial Least Squares (PLS) Discriminant Analysis",
     short.name = "plsdacaret",
     callees = c("plsda", "plsr")
@@ -25,7 +25,7 @@ trainLearner.classif.plsdaCaret = function(.learner, .task, .subset, .weights, .
 predictLearner.classif.plsdaCaret = function(.learner, .model, .newdata, ...) {
   type = ifelse(.learner$predict.type == "response", "class", "prob")
   p = predict(.model$learner.model, newdata = .newdata, type = type, ...)
-  if (type == "prob"){
+  if (type == "prob") {
     p = p[, , 1]
   }
   return(p)
