@@ -21,7 +21,7 @@ makeRLearner.regr.cvglmnet = function() {
       makeNumericVectorLearnerParam(id = "lower.limits", upper = 0),
       makeNumericVectorLearnerParam(id = "upper.limits", lower = 0),
       makeIntegerLearnerParam(id = "maxit", default = 100000L, lower = 1L),
-      #FIXME Data dependent default. If n.features < 500 'covariance', 'naive' otherwise
+      # FIXME Data dependent default. If n.features < 500 'covariance', 'naive' otherwise
       makeDiscreteLearnerParam(id = "type.gaussian", values = c("covariance", "naive")),
       makeNumericLearnerParam(id = "fdev", default = 1.0e-5, lower = 0, upper = 1),
       makeNumericLearnerParam(id = "devmax", default = 0.999, lower = 0, upper = 1),
@@ -40,18 +40,21 @@ makeRLearner.regr.cvglmnet = function() {
     glmnet uses a global control object for its parameters. mlr resets all control parameters to their defaults
     before setting the specified parameters and after training.
     If you are setting glmnet.control parameters through glmnet.control,
-    you need to save and re-set them after running the glmnet learner."
+    you need to save and re-set them after running the glmnet learner.",
+    callees = c("cv.glmnet", "glmnet", "glmnet.control", "predict.cv.glmnet")
   )
 }
 
 #' @export
 trainLearner.regr.cvglmnet = function(.learner, .task, .subset, .weights = NULL, ...) {
+
   d = getTaskData(.task, .subset, target.extra = TRUE)
   info = getFixDataInfo(d$data, factors.to.dummies = TRUE, ordered.to.int = TRUE)
   args = c(list(x = as.matrix(fixDataForLearner(d$data, info)), y = d$target), list(...))
   rm(d)
-  if (!is.null(.weights))
+  if (!is.null(.weights)) {
     args$weights = .weights
+  }
 
   glmnet::glmnet.control(factory = TRUE)
   saved.ctrl = glmnet::glmnet.control()
