@@ -4,7 +4,7 @@ makeRLearner.regr.gbm = function() {
     cl = "regr.gbm",
     package = "gbm",
     par.set = makeParamSet(
-      makeDiscreteLearnerParam(id = "distribution", default = "gaussian", values = c("gaussian", "laplace", "poisson", "tdist")),
+      makeDiscreteLearnerParam(id = "distribution", default = "gaussian", values = c("gaussian", "laplace", "poisson", "tdist", "quantile")),
       # FIXME default for distribution in gbm() is bernoulli
       makeIntegerLearnerParam(id = "n.trees", default = 100L, lower = 1L),
       makeIntegerLearnerParam(id = "cv.folds", default = 0L),
@@ -13,6 +13,8 @@ makeRLearner.regr.gbm = function() {
       makeNumericLearnerParam(id = "shrinkage", default = 0.001, lower = 0),
       makeNumericLearnerParam(id = "bag.fraction", default = 0.5, lower = 0, upper = 1),
       makeNumericLearnerParam(id = "train.fraction", default = 1, lower = 0, upper = 1),
+      makeNumericLearnerParam(id = "alpha", default = 0.5, lower = 0, upper = 1,
+        requires = quote(distribution == "quantile")),
       makeLogicalLearnerParam(id = "keep.data", default = TRUE, tunable = FALSE),
       makeLogicalLearnerParam(id = "verbose", default = FALSE, tunable = FALSE)
     ),
@@ -26,15 +28,28 @@ makeRLearner.regr.gbm = function() {
 }
 
 #' @export
-trainLearner.regr.gbm = function(.learner, .task, .subset, .weights = NULL,  ...) {
+trainLearner.regr.gbm = function(.learner, .task, .subset, .weights = NULL, ...) {
+
   f = getTaskFormula(.task)
-  if (is.null(.weights)) {
-    f = getTaskFormula(.task)
-    gbm::gbm(f, data = getTaskData(.task, .subset), ...)
-  } else  {
-    f = getTaskFormula(.task)
-    gbm::gbm(f, data = getTaskData(.task, .subset), weights = .weights, ...)
+
+  params = list(...)
+  if ("alpha" %in% names(params)) {
+    alpha = params$alpha
+    params$alpha = NULL
+  } else {
+    alpha = 0.5
   }
+  if (params$distribution == "quantile") {
+    params$distribution = list(name = "quantile", alpha = alpha)
+  }
+  params$formula = f
+  params$data = getTaskData(.task, .subset)
+
+  if (!is.null(.weights)) {
+    params$weights = .weights
+  }
+
+  do.call(gbm::gbm, params)
 }
 
 #' @export
@@ -46,4 +61,4 @@ predictLearner.regr.gbm = function(.learner, .model, .newdata, ...) {
 #' @export
 getFeatureImportanceLearner.regr.gbm = function(.learner, .model, ...) {
   getFeatureImportanceLearner.classif.gbm(.learner, .model, ...)
-  }
+}
