@@ -7,7 +7,6 @@ makeRLearner.regr.ranger = function() {
     par.set = makeParamSet(
       makeIntegerLearnerParam(id = "num.trees", lower = 1L, default = 500L),
       makeIntegerLearnerParam(id = "mtry", lower = 1L),
-      makeNumericLearnerParam(id = "mtry.perc", lower = 0, upper = 1),
       makeIntegerLearnerParam(id = "min.node.size", lower = 1L, default = 5L),
       makeLogicalLearnerParam(id = "replace", default = TRUE),
       makeNumericLearnerParam(id = "sample.fraction", lower = 0L, upper = 1L),
@@ -24,41 +23,38 @@ makeRLearner.regr.ranger = function() {
       makeDiscreteLearnerParam(id = "splitrule", values = c("variance", "extratrees", "maxstat"), default = "variance"),
       makeIntegerLearnerParam(id = "num.random.splits", lower = 1L, default = 1L, requires = quote(splitrule == "extratrees")),
       makeNumericLearnerParam(id = "alpha", lower = 0L, upper = 1L, default = 0.5, requires = quote(splitrule == "maxstat")),
-      makeNumericLearnerParam(id = "minprop", lower = 0L, upper = 1L, default = 0.1, requires = quote(splitrule == "maxstat")),
-      makeLogicalLearnerParam(id = "keep.inbag", default = FALSE, tunable = FALSE)
+      makeNumericLearnerParam(id = "minprop", lower = 0, upper = 0.5, default = 0.1, requires = quote(splitrule == "maxstat")),
+      makeLogicalLearnerParam(id = "keep.inbag", default = FALSE, tunable = FALSE),
+      makeDiscreteLearnerParam(id = "se.method", default = "infjack", values = c("jack",  "infjack"), requires = quote(keep.inbag == TRUE), when = "predict")
     ),
     par.vals = list(num.threads = 1L, verbose = FALSE, respect.unordered.factors = "order"),
-    properties = c("numerics", "factors", "ordered", "oobpreds", "featimp", "se"),
+    properties = c("numerics", "factors", "ordered", "oobpreds", "featimp", "se", "weights"),
     name = "Random Forests",
     short.name = "ranger",
-    note = "By default, internal parallelization is switched off (`num.threads = 1`), `verbose` output is disabled, `respect.unordered.factors` is set to `order` for all splitrules. All settings are changeable. `mtry.perc` sets `mtry` to `mtry.perc*getTaskNFeats(.task)`. Default for `mtry` is the floor of square root of number of features in task.",
+    note = "By default, internal parallelization is switched off (`num.threads = 1`), `verbose` output is disabled, `respect.unordered.factors` is set to `order` for all splitrules. All settings are changeable. `mtry.perc` sets `mtry` to `mtry.perc*getTaskNFeats(.task)`. Default for `mtry` is the floor of square root of number of features in task. Se estimation is mc bias-corrected jackknife after bootstrap, see '?regr.randomForest' for more details.",
     callees = "ranger"
   )
 }
 
 #' @export
-trainLearner.regr.ranger = function(.learner, .task, .subset, .weights, keep.inbag = NULL, mtry, mtry.perc, ...) {
+trainLearner.regr.ranger = function(.learner, .task, .subset, .weights = NULL, keep.inbag = NULL, ...) {
   tn = getTaskTargetNames(.task)
-  if (missing(mtry)) {
-    if (missing(mtry.perc)) {
-      mtry = floor(sqrt(getTaskNFeats(.task)))
-    } else {
-      mtry = max(1, floor(mtry.perc * getTaskNFeats(.task)))
-    }
-  }
-  keep.inbag = if (is.null(keep.inbag)) FALSE else keep.inbag
-  keep.inbag = if (.learner$predict.type == "se") TRUE else keep.inbag
-  ranger::ranger(formula = NULL, dependent.variable = tn, data = getTaskData(.task, .subset), keep.inbag = keep.inbag, mtry = mtry, ...)
+  if (is.null(keep.inbag)) keep.inbag = (.learner$predict.type == "se") # needed for jacknife and infjack!
+  ranger::ranger(formula = NULL, dependent.variable = tn, data = getTaskData(.task, .subset),
+    case.weights = .weights, keep.inbag = keep.inbag, ...)
 }
 
 #' @export
-predictLearner.regr.ranger = function(.learner, .model, .newdata, ...) {
-  type = if (.learner$predict.type == "se") "se" else "response"
-  p = predict(object = .model$learner.model, data = .newdata, type = type, ...)
+predictLearner.regr.ranger = function(.learner, .model, .newdata, se.method = "sd", ...) {
+  pred = predict(object = .model$learner.model, data = .newdata, type = ifelse(.learner$predict.type == "se", "se", "response"), ...)
+  p = pred$predictions
+  if (is.matrix(p)) { # if someone set predict.all = TRUE for ranger
+    p = rowMeans(pred$predictions)
+  }
   if (.learner$predict.type == "se") {
-    return(cbind(p$predictions, p$se))
+    return(cbind(p, pred$se))
   } else {
-    return(p$predictions)
+    return(p)
   }
 }
 
