@@ -5,7 +5,7 @@ makeRLearner.regr.xgboost = function() {
     package = "xgboost",
     par.set = makeParamSet(
       # we pass all of what goes in 'params' directly to ... of xgboost
-      #makeUntypedLearnerParam(id = "params", default = list()),
+      # makeUntypedLearnerParam(id = "params", default = list()),
       makeDiscreteLearnerParam(id = "booster", default = "gbtree", values = c("gbtree", "gblinear", "dart")),
       makeUntypedLearnerParam(id = "watchlist", default = NULL, tunable = FALSE),
       makeNumericLearnerParam(id = "eta", default = 0.3, lower = 0, upper = 1),
@@ -41,11 +41,11 @@ makeRLearner.regr.xgboost = function() {
       makeNumericLearnerParam(id = "rate_drop", default = 0, lower = 0, upper = 1, requires = quote(booster == "dart")),
       makeNumericLearnerParam(id = "skip_drop", default = 0, lower = 0, upper = 1, requires = quote(booster == "dart")),
       # TODO: uncomment the following after the next CRAN update, and set max_depth's lower = 0L
-      #makeLogicalLearnerParam(id = "one_drop", default = FALSE, requires = quote(booster == "dart")),
-      #makeDiscreteLearnerParam(id = "tree_method", default = "exact", values = c("exact", "hist"), requires = quote(booster != "gblinear")),
-      #makeDiscreteLearnerParam(id = "grow_policy", default = "depthwise", values = c("depthwise", "lossguide"), requires = quote(tree_method == "hist")),
-      #makeIntegerLearnerParam(id = "max_leaves", default = 0L, lower = 0L, requires = quote(grow_policy == "lossguide")),
-      #makeIntegerLearnerParam(id = "max_bin", default = 256L, lower = 2L, requires = quote(tree_method == "hist")),
+      # makeLogicalLearnerParam(id = "one_drop", default = FALSE, requires = quote(booster == "dart")),
+      # makeDiscreteLearnerParam(id = "tree_method", default = "exact", values = c("exact", "hist"), requires = quote(booster != "gblinear")),
+      # makeDiscreteLearnerParam(id = "grow_policy", default = "depthwise", values = c("depthwise", "lossguide"), requires = quote(tree_method == "hist")),
+      # makeIntegerLearnerParam(id = "max_leaves", default = 0L, lower = 0L, requires = quote(grow_policy == "lossguide")),
+      # makeIntegerLearnerParam(id = "max_bin", default = 256L, lower = 2L, requires = quote(tree_method == "hist")),
       makeUntypedLearnerParam(id = "callbacks", default = list(), tunable = FALSE)
     ),
     par.vals = list(nrounds = 1L, verbose = 0L),
@@ -58,20 +58,24 @@ makeRLearner.regr.xgboost = function() {
 }
 
 #' @export
-trainLearner.regr.xgboost = function(.learner, .task, .subset, .weights = NULL,  ...) {
+trainLearner.regr.xgboost = function(.learner, .task, .subset, .weights = NULL, ...) {
+
   parlist = list(...)
 
-  if (is.null(parlist$objective))
+  if (is.null(parlist$objective)) {
     parlist$objective = "reg:linear"
+  }
 
   task.data = getTaskData(.task, .subset, target.extra = TRUE)
   parlist$data = xgboost::xgb.DMatrix(data = data.matrix(task.data$data), label = task.data$target)
 
-  if (!is.null(.weights))
+  if (!is.null(.weights)) {
     xgboost::setinfo(parlist$data, "weight", .weights)
+  }
 
-  if (is.null(parlist$watchlist))
+  if (is.null(parlist$watchlist)) {
     parlist$watchlist = list(train = parlist$data)
+  }
 
   do.call(xgboost::xgb.train, parlist)
 }
