@@ -7,7 +7,7 @@
 #' The measure itself knows whether it wants to be minimized or maximized and for what tasks it is applicable.
 #'
 #' All supported measures can be found by [listMeasures] or as a table
-#' in the tutorial appendix: <https://mlr-org.github.io/mlr/articles/measures.html>.
+#' in the tutorial appendix: <https://mlr.mlr-org.com/articles/tutorial/measures.html>.
 #'
 #' If you want a measure for a misclassification cost matrix, look at [makeCostMeasure].
 #' If you want to implement your own measure, look at [makeMeasure].
@@ -46,11 +46,10 @@ NULL
 featperc = makeMeasure(id = "featperc", minimize = TRUE, best = 0, worst = 1,
   properties = c("classif", "classif.multi", "multilabel", "regr", "surv", "costsens", "cluster", "req.model", "req.pred"),
   name = "Percentage of original features used for model",
-  note =  "Useful for feature selection.",
+  note = "Useful for feature selection.",
   fun = function(task, model, pred, feats, extra.args) {
     length(model$features) / sum(pred$task.desc$n.feat)
-  }
-)
+  })
 
 #' @export timetrain
 #' @rdname measures
@@ -60,8 +59,7 @@ timetrain = makeMeasure(id = "timetrain", minimize = TRUE, best = 0, worst = Inf
   name = "Time of fitting the model",
   fun = function(task, model, pred, feats, extra.args) {
     model$time
-  }
-)
+  })
 
 #' @export timepredict
 #' @rdname measures
@@ -71,8 +69,7 @@ timepredict = makeMeasure(id = "timepredict", minimize = TRUE, best = 0, worst =
   name = "Time of predicting test set",
   fun = function(task, model, pred, feats, extra.args) {
     pred$time
-  }
-)
+  })
 
 #' @export timeboth
 #' @rdname measures
@@ -82,8 +79,7 @@ timeboth = makeMeasure(id = "timeboth", minimize = TRUE, best = 0, worst = Inf,
   name = "timetrain + timepredict",
   fun = function(task, model, pred, feats, extra.args) {
     model$time + pred$time
-  }
-)
+  })
 
 ###############################################################################
 ### regression ###
@@ -98,8 +94,7 @@ sse = makeMeasure(id = "sse", minimize = TRUE, best = 0, worst = Inf,
   note = "Defined as: sum((response - truth)^2)",
   fun = function(task, model, pred, feats, extra.args) {
     measureSSE(pred$data$truth, pred$data$response)
-  }
-)
+  })
 
 #' @export measureSSE
 #' @rdname measures
@@ -117,8 +112,7 @@ mse = makeMeasure(id = "mse", minimize = TRUE, best = 0, worst = Inf,
   note = "Defined as: mean((response - truth)^2)",
   fun = function(task, model, pred, feats, extra.args) {
     measureMSE(pred$data$truth, pred$data$response)
-  }
-)
+  })
 
 #' @export measureMSE
 #' @rdname measures
@@ -157,8 +151,7 @@ medse = makeMeasure(id = "medse", minimize = TRUE, best = 0, worst = Inf,
   note = "Defined as: median((response - truth)^2).",
   fun = function(task, model, pred, feats, extra.args) {
     measureMEDSE(pred$data$truth, pred$data$response)
-  }
-)
+  })
 
 #' @export measureMEDSE
 #' @rdname measures
@@ -176,8 +169,7 @@ sae = makeMeasure(id = "sae", minimize = TRUE, best = 0, worst = Inf,
   note = "Defined as: sum(abs(response - truth))",
   fun = function(task, model, pred, feats, extra.args) {
     measureSAE(pred$data$truth, pred$data$response)
-  }
-)
+  })
 
 #' @export measureSAE
 #' @rdname measures
@@ -195,8 +187,7 @@ mae = makeMeasure(id = "mae", minimize = TRUE, best = 0, worst = Inf,
   note = "Defined as: mean(abs(response - truth))",
   fun = function(task, model, pred, feats, extra.args) {
     measureMAE(pred$data$truth, pred$data$response)
-  }
-)
+  })
 
 #' @export measureMAE
 #' @rdname measures
@@ -214,8 +205,7 @@ medae = makeMeasure(id = "medae", minimize = TRUE, best = 0, worst = Inf,
   note = "Defined as: median(abs(response - truth)).",
   fun = function(task, model, pred, feats, extra.args) {
     measureMEDAE(pred$data$truth, pred$data$response)
-  }
-)
+  })
 
 #' @export measureMEDAE
 #' @rdname measures
@@ -233,8 +223,7 @@ rsq = makeMeasure(id = "rsq", minimize = FALSE, best = 1, worst = -Inf,
   note = "Also called R-squared, which is 1 - residual_sum_of_squares / total_sum_of_squares.",
   fun = function(task, model, pred, feats, extra.args) {
     measureRSQ(pred$data$truth, pred$data$response)
-  }
-)
+  })
 
 #' @export measureRSQ
 #' @rdname measures
@@ -242,7 +231,7 @@ rsq = makeMeasure(id = "rsq", minimize = FALSE, best = 1, worst = -Inf,
 measureRSQ = function(truth, response) {
   rss = measureSSE(truth, response)
   ess = sum((truth - mean(truth))^2L)
-  if (ess == 0){
+  if (ess == 0) {
     warning("Measure is undefined if all truth values are equal.")
     return(NA_real_)
   }
@@ -258,8 +247,7 @@ expvar = makeMeasure(id = "expvar", minimize = FALSE, best = 1, worst = 0,
   note = "Similar to measure rsq (R-squared). Defined as explained_sum_of_squares / total_sum_of_squares.",
   fun = function(task, model, pred, feats, extra.args) {
     measureEXPVAR(pred$data$truth, pred$data$response)
-  }
-)
+  })
 
 #' @export measureEXPVAR
 #' @rdname measures
@@ -267,7 +255,7 @@ expvar = makeMeasure(id = "expvar", minimize = FALSE, best = 1, worst = 0,
 measureEXPVAR = function(truth, response) {
   regss = sum((response - mean(truth))^2L)
   ess = sum((truth - mean(truth))^2L)
-  if (ess == 0){
+  if (ess == 0) {
     warning("Measure is undefined if all truth values are equal.")
     return(NA_real_)
   }
@@ -284,13 +272,12 @@ arsq = makeMeasure(id = "arsq", minimize = FALSE, best = 1, worst = 0,
   fun = function(task, model, pred, feats, extra.args) {
     n = length(pred$data$truth)
     p = length(model$features)
-    if (n == p + 1){
+    if (n == p + 1) {
       warning("Adjusted R-squared is undefined if the number observations is equal to the number of independent variables plus one.")
       return(NA_real_)
     }
     1 - (1 - measureRSQ(pred$data$truth, pred$data$response)) * (p / (n - p - 1L))
-  }
-)
+  })
 
 #' @export rrse
 #' @rdname measures
@@ -301,15 +288,14 @@ rrse = makeMeasure(id = "rrse", minimize = TRUE, best = 0, worst = Inf,
   note = "Defined as sqrt (sum_of_squared_errors / total_sum_of_squares). Undefined for single instances and when every truth value is identical. In this case the output will be NA.",
   fun = function(task, model, pred, feats, extra.args) {
     measureRRSE(pred$data$truth, pred$data$response)
-  }
-)
+  })
 
 #' @export measureRRSE
 #' @rdname measures
 #' @format none
-measureRRSE = function(truth, response){
+measureRRSE = function(truth, response) {
   tss = sum((truth - mean(truth))^2L)
-  if (tss == 0){
+  if (tss == 0) {
     warning("Measure is undefined if all truth values are equal.")
     return(NA_real_)
   }
@@ -325,15 +311,14 @@ rae = makeMeasure(id = "rae", minimize = TRUE, best = 0, worst = Inf,
   note = "Defined as sum_of_absolute_errors / mean_absolute_deviation. Undefined for single instances and when every truth value is identical. In this case the output will be NA.",
   fun = function(task, model, pred, feats, extra.args) {
     measureRAE(pred$data$truth, pred$data$response)
-  }
-)
+  })
 
 #' @export measureRAE
 #' @rdname measures
 #' @format none
-measureRAE = function(truth, response){
+measureRAE = function(truth, response) {
   meanad = sum(abs(truth - mean(truth)))
-  if (meanad == 0){
+  if (meanad == 0) {
     warning("Measure is undefined if all truth values are equal.")
     return(NA_real_)
   }
@@ -349,14 +334,13 @@ mape = makeMeasure(id = "mape", minimize = TRUE, best = 0, worst = Inf,
   note = "Defined as the abs(truth_i - response_i) / truth_i. Won't work if any truth value is equal to zero. In this case the output will be NA.",
   fun = function(task, model, pred, feats, extra.args) {
     measureMAPE(pred$data$truth, pred$data$response)
-  }
-)
+  })
 
 #' @export measureMAPE
 #' @rdname measures
 #' @format none
-measureMAPE = function(truth, response){
-  if (any(truth == 0)){
+measureMAPE = function(truth, response) {
+  if (any(truth == 0)) {
     warning("Measure is undefined if any truth value is equal to 0.")
     return(NA_real_)
   }
@@ -374,17 +358,18 @@ msle = makeMeasure(id = "msle", minimize = TRUE, best = 0, worst = Inf,
   to compute the measure.",
   fun = function(task, model, pred, feats, extra.args) {
     measureMSLE(pred$data$truth, pred$data$response)
-  }
-)
+  })
 
 #' @export measureMSLE
 #' @rdname measures
 #' @format none
 measureMSLE = function(truth, response) {
-  if (any(truth < -1))
+  if (any(truth < -1)) {
     stop("All truth values must be greater or equal -1")
-  if (any(response < -1))
+  }
+  if (any(response < -1)) {
     stop("All predicted values must be greater or equal -1")
+  }
 
   mean((log(response + 1) - log(truth + 1))^2)
 }
@@ -401,8 +386,7 @@ rmsle = makeMeasure(id = "rmsle", minimize = TRUE, best = 0, worst = Inf,
   must be greater or equal '-1' to compute the measure.",
   fun = function(task, model, pred, feats, extra.args) {
     measureRMSLE(pred$data$truth, pred$data$response)
-  }
-)
+  })
 
 #' @export measureRMSLE
 #' @rdname measures
@@ -421,8 +405,7 @@ kendalltau = makeMeasure(id = "kendalltau", minimize = FALSE, best = 1, worst =
   See Rosset et al.: http://citeseerx.ist.psu.edu/viewdoc/download?doi=10.1.1.95.1398&rep=rep1&type=pdf.",
   fun = function(task, model, pred, feats, extra.args) {
     measureKendallTau(pred$data$truth, pred$data$response)
-  }
-)
+  })
 
 #' @export measureKendallTau
 #' @rdname measures
@@ -441,8 +424,7 @@ spearmanrho = makeMeasure(id = "spearmanrho", minimize = FALSE, best = 1, worst
   See Rosset et al.: http://citeseerx.ist.psu.edu/viewdoc/download?doi=10.1.1.95.1398&rep=rep1&type=pdf.",
   fun = function(task, model, pred, feats, extra.args) {
     measureSpearmanRho(pred$data$truth, pred$data$response)
-  }
-)
+  })
 
 #' @export measureSpearmanRho
 #' @rdname measures
@@ -463,8 +445,7 @@ mmce = makeMeasure(id = "mmce", minimize = TRUE, best = 0, worst = 1,
   note = "Defined as: mean(response != truth)",
   fun = function(task, model, pred, feats, extra.args) {
     measureMMCE(pred$data$truth, pred$data$response)
-  }
-)
+  })
 
 #' @export measureMMCE
 #' @rdname measures
@@ -482,8 +463,7 @@ acc = makeMeasure(id = "acc", minimize = FALSE, best = 1, worst = 0,
   note = "Defined as: mean(response == truth)",
   fun = function(task, model, pred, feats, extra.args) {
     measureACC(pred$data$truth, pred$data$response)
-  }
-)
+  })
 
 #' @export measureACC
 #' @rdname measures
@@ -501,16 +481,16 @@ ber = makeMeasure(id = "ber", minimize = TRUE, best = 0, worst = 1,
   note = "Mean of misclassification error rates on all individual classes.",
   fun = function(task, model, pred, feats, extra.args) {
     measureBER(pred$data$truth, pred$data$response)
-  }
-)
+  })
 
 #' @export measureBER
 #' @rdname measures
 #' @format none
 measureBER = function(truth, response) {
   # special case for predictions from FailureModel
-  if (anyMissing(response))
+  if (anyMissing(response)) {
     return(NA_real_)
+  }
   mean(diag(1 - (table(truth, response) / table(truth, truth))))
 }
 
@@ -523,14 +503,13 @@ multiclass.aunu = makeMeasure(id = "multiclass.aunu", minimize = FALSE, best = 1
   note = "Computes the AUC treating a c-dimensional classifier as c two-dimensional classifiers, where classes are assumed to have uniform distribution, in order to have a measure which is independent of class distribution change. See Ferri et al.: https://www.math.ucdavis.edu/~saito/data/roc/ferri-class-perf-metrics.pdf.",
   fun = function(task, model, pred, feats, extra.args) {
     measureAUNU(getPredictionProbabilities(pred, pred$task.desc$class.levels), pred$data$truth)
-  }
-)
+  })
 
 #' @export measureAUNU
 #' @rdname measures
 #' @format none
 measureAUNU = function(probabilities, truth) {
-  if (length(unique(truth)) != nlevels(truth)){
+  if (length(unique(truth)) != nlevels(truth)) {
     warning("Measure is undefined if there isn't at least one sample per class.")
     return(NA_real_)
   }
@@ -546,14 +525,13 @@ multiclass.aunp = makeMeasure(id = "multiclass.aunp", minimize = FALSE, best = 1
   note = "Computes the AUC treating a c-dimensional classifier as c two-dimensional classifiers, taking into account the prior probability of each class. See Ferri et al.: https://www.math.ucdavis.edu/~saito/data/roc/ferri-class-perf-metrics.pdf.",
   fun = function(task, model, pred, feats, extra.args) {
     measureAUNP(getPredictionProbabilities(pred, pred$task.desc$class.levels), pred$data$truth)
-  }
-)
+  })
 
 #' @export measureAUNP
 #' @rdname measures
 #' @format none
 measureAUNP = function(probabilities, truth) {
-  if (length(unique(truth)) != nlevels(truth)){
+  if (length(unique(truth)) != nlevels(truth)) {
     warning("Measure is undefined if there isn't at least one sample per class.")
     return(NA_real_)
   }
@@ -566,11 +544,10 @@ measureAUNP = function(probabilities, truth) {
 multiclass.au1u = makeMeasure(id = "multiclass.au1u", minimize = FALSE, best = 1, worst = 0.5,
   properties = c("classif", "classif.multi", "req.pred", "req.truth", "req.prob"),
   name = "Average 1 vs. 1 multiclass AUC",
-  note =  "Computes AUC of c(c - 1) binary classifiers (all possible pairwise combinations) while considering uniform distribution of the classes. See Ferri et al.: https://www.math.ucdavis.edu/~saito/data/roc/ferri-class-perf-metrics.pdf.",
+  note = "Computes AUC of c(c - 1) binary classifiers (all possible pairwise combinations) while considering uniform distribution of the classes. See Ferri et al.: https://www.math.ucdavis.edu/~saito/data/roc/ferri-class-perf-metrics.pdf.",
   fun = function(task, model, pred, feats, extra.args) {
     measureAU1U(getPredictionProbabilities(pred, pred$task.desc$class.levels), pred$data$truth)
-  }
-)
+  })
 
 #' @export measureAU1U
 #' @rdname measures
@@ -590,8 +567,7 @@ multiclass.au1p = makeMeasure(id = "multiclass.au1p", minimize = FALSE, best = 1
   note = "Computes AUC of c(c - 1) binary classifiers while considering the a priori distribution of the classes. See Ferri et al.: https://www.math.ucdavis.edu/~saito/data/roc/ferri-class-perf-metrics.pdf.",
   fun = function(task, model, pred, feats, extra.args) {
     measureAU1P(getPredictionProbabilities(pred, pred$task.desc$class.levels), pred$data$truth)
-  }
-)
+  })
 
 #' @export measureAU1P
 #' @rdname measures
@@ -613,8 +589,7 @@ multiclass.brier = makeMeasure(id = "multiclass.brier", minimize = TRUE, best =
   note = "Defined as: (1/n) sum_i sum_j (y_ij - p_ij)^2, where y_ij = 1 if observation i has class j (else 0), and p_ij is the predicted probability of observation i for class j. From http://docs.lib.noaa.gov/rescue/mwr/078/mwr-078-01-0001.pdf.",
   fun = function(task, model, pred, feats, extra.args) {
     measureMulticlassBrier(getPredictionProbabilities(pred, pred$task.desc$class.levels), pred$data$truth)
-  }
-)
+  })
 
 #' @export measureMulticlassBrier
 #' @rdname measures
@@ -634,15 +609,14 @@ logloss = makeMeasure(id = "logloss", minimize = TRUE, best = 0, worst = Inf,
   note = "Defined as: -mean(log(p_i)), where p_i is the predicted probability of the true class of observation i. Inspired by https://www.kaggle.com/wiki/MultiClassLogLoss.",
   fun = function(task, model, pred, feats, extra.args) {
     measureLogloss(getPredictionProbabilities(pred, cl = pred$task.desc$class.levels), pred$data$truth)
-  }
-)
+  })
 
 #' @export measureLogloss
 #' @rdname measures
 #' @format none
-measureLogloss = function(probabilities, truth){
+measureLogloss = function(probabilities, truth) {
   eps = 1e-15
-  #let's confine the predicted probabilities to [eps,1 - eps], so logLoss doesn't reach infinity under any circumstance
+  # let's confine the predicted probabilities to [eps,1 - eps], so logLoss doesn't reach infinity under any circumstance
   probabilities[probabilities > 1 - eps] = 1 - eps
   probabilities[probabilities < eps] = eps
   truth = match(as.character(truth), colnames(probabilities))
@@ -660,13 +634,12 @@ ssr = makeMeasure(id = "ssr", minimize = FALSE, best = 1, worst = 0,
   See: Bickel, J. E. (2007). Some comparisons among quadratic, spherical, and logarithmic scoring rules. Decision Analysis, 4(2), 49-65.",
   fun = function(task, model, pred, feats, extra.args) {
     measureSSR(getPredictionProbabilities(pred, cl = pred$task.desc$class.levels), pred$data$truth)
-  }
-)
+  })
 
 #' @export measureSSR
 #' @rdname measures
 #' @format none
-measureSSR = function(probabilities, truth){
+measureSSR = function(probabilities, truth) {
   truth = match(as.character(truth), colnames(probabilities))
   p = getRowEls(probabilities, truth)
   mean(p / sqrt(rowSums(probabilities^2)))
@@ -683,14 +656,13 @@ qsr = makeMeasure(id = "qsr", minimize = FALSE, best = 1, worst = -1,
   See: Bickel, J. E. (2007). Some comparisons among quadratic, spherical, and logarithmic scoring rules. Decision Analysis, 4(2), 49-65.",
   fun = function(task, model, pred, feats, extra.args) {
     measureQSR(getPredictionProbabilities(pred, cl = pred$task.desc$class.levels), pred$data$truth)
-  }
-)
+  })
 
 #' @export measureQSR
 #' @rdname measures
 #' @format none
-measureQSR = function(probabilities, truth){
-  #We add this line because binary tasks only output one probability column
+measureQSR = function(probabilities, truth) {
+  # We add this line because binary tasks only output one probability column
   if (is.null(dim(probabilities))) probabilities = cbind(probabilities, 1 - probabilities)
   truth = factor(truth, levels = colnames(probabilities))
   1 - mean(rowSums((probabilities - createDummyFeatures(truth))^2))
@@ -707,13 +679,12 @@ lsr = makeMeasure(id = "lsr", minimize = FALSE, best = 0, worst = -Inf,
   See: Bickel, J. E. (2007). Some comparisons among quadratic, spherical, and logarithmic scoring rules. Decision Analysis, 4(2), 49-65.",
   fun = function(task, model, pred, feats, extra.args) {
     measureLSR(getPredictionProbabilities(pred, cl = pred$task.desc$class.levels), pred$data$truth)
-  }
-)
+  })
 
 #' @export measureLSR
 #' @rdname measures
 #' @format none
-measureLSR = function(probabilities, truth){
+measureLSR = function(probabilities, truth) {
   -1 * measureLogloss(probabilities, truth)
 }
 
@@ -727,13 +698,13 @@ kappa = makeMeasure(id = "kappa", minimize = FALSE, best = 1, worst = -1,
     agreement' and pe = 'expected agremeent frequency under independence",
   fun = function(task, model, pred, feats, extra.args) {
     measureKAPPA(pred$data$truth, pred$data$response)
-  }
-)
+  })
 
 #' @export measureKAPPA
 #' @rdname measures
 #' @format none
 measureKAPPA = function(truth, response) {
+
   # get confusion matrix
   conf.mat = table(truth, response)
   conf.mat = conf.mat / sum(conf.mat)
@@ -760,13 +731,13 @@ wkappa = makeMeasure(id = "wkappa", minimize = FALSE, best = 1, worst = -1,
     the weight matrix measures seriousness of disagreement with the squared euclidean metric.",
   fun = function(task, model, pred, feats, extra.args) {
     measureWKAPPA(pred$data$truth, pred$data$response)
-  }
-)
+  })
 
 #' @export measureWKAPPA
 #' @rdname measures
 #' @format none
 measureWKAPPA = function(truth, response) {
+
   # get confusion matrix
   conf.mat = table(truth, response)
   conf.mat = conf.mat / sum(conf.mat)
@@ -795,11 +766,11 @@ auc = makeMeasure(id = "auc", minimize = FALSE, best = 1, worst = 0,
   name = "Area under the curve",
   note = "Integral over the graph that results from computing fpr and tpr for many different thresholds.",
   fun = function(task, model, pred, feats, extra.args) {
-    if (anyMissing(pred$data$response) || length(unique(pred$data$truth)) == 1L)
+    if (anyMissing(pred$data$response) || length(unique(pred$data$truth)) == 1L) {
       return(NA_real_)
+    }
     measureAUC(getPredictionProbabilities(pred), pred$data$truth, pred$task.desc$negative, pred$task.desc$positive)
-  }
-)
+  })
 
 #' @export measureAUC
 #' @rdname measures
@@ -813,7 +784,7 @@ measureAUC = function(probabilities, truth, negative, positive) {
   if (length(unique(i)) < 2L) {
     stop("truth vector must have at least two classes")
   }
-  #Use fast ranking function from data.table for larger vectors
+  # Use fast ranking function from data.table for larger vectors
   if (length(i) > 5000L) {
     r = frankv(probabilities)
   } else {
@@ -835,8 +806,7 @@ brier = makeMeasure(id = "brier", minimize = TRUE, best = 0, worst = 1,
   multiclass.brier is the sum over all one vs. all comparisons and for a binary classifcation 2 * brier.",
   fun = function(task, model, pred, feats, extra.args) {
     measureBrier(getPredictionProbabilities(pred), pred$data$truth, pred$task.desc$negative, pred$task.desc$positive)
-  }
-)
+  })
 
 #' @export measureBrier
 #' @rdname measures
@@ -855,8 +825,7 @@ brier.scaled = makeMeasure(id = "brier.scaled", minimize = FALSE, best = 1, wors
   note = "Brier score scaled to [0,1], see http://www.ncbi.nlm.nih.gov/pmc/articles/PMC3575184/.",
   fun = function(task, model, pred, feats, extra.args) {
     measureBrierScaled(getPredictionProbabilities(pred), pred$data$truth, pred$task.desc$negative, pred$task.desc$positive)
-  }
-)
+  })
 
 #' @export measureBrierScaled
 #' @rdname measures
@@ -878,14 +847,13 @@ bac = makeMeasure(id = "bac", minimize = FALSE, best = 1, worst = 0,
   note = "For binary tasks, mean of true positive rate and true negative rate.",
   fun = function(task, model, pred, feats, extra.args) {
     measureBAC(pred$data$truth, pred$data$response)
-  }
-)
+  })
 
 #' @export measureBAC
 #' @rdname measures
 #' @format none
 measureBAC = function(truth, response) {
-    mean(diag(table(truth, response) / table(truth, truth)))
+  mean(diag(table(truth, response) / table(truth, truth)))
 }
 
 #' @export tp
@@ -897,8 +865,7 @@ tp = makeMeasure(id = "tp", minimize = FALSE, best = Inf, worst = 0,
   note = "Sum of all correctly classified observations in the positive class.",
   fun = function(task, model, pred, feats, extra.args) {
     measureTP(pred$data$truth, pred$data$response, pred$task.desc$positive)
-  }
-)
+  })
 
 #' @export measureTP
 #' @rdname measures
@@ -916,8 +883,7 @@ tn = makeMeasure(id = "tn", minimize = FALSE, best = Inf, worst = 0,
   note = "Sum of correctly classified observations in the negative class. Also called correct rejections.",
   fun = function(task, model, pred, feats, extra.args) {
     measureTN(pred$data$truth, pred$data$response, pred$task.desc$negative)
-  }
-)
+  })
 
 #' @export measureTN
 #' @rdname measures
@@ -935,8 +901,7 @@ fp = makeMeasure(id = "fp", minimize = TRUE, best = 0, worst = Inf,
   note = "Sum of misclassified observations in the positive class. Also called false alarms.",
   fun = function(task, model, pred, feats, extra.args) {
     measureFP(pred$data$truth, pred$data$response, pred$task.desc$positive)
-  }
-)
+  })
 
 #' @export measureFP
 #' @rdname measures
@@ -954,8 +919,7 @@ fn = makeMeasure(id = "fn", minimize = TRUE, best = 0, worst = Inf,
   note = "Sum of misclassified observations in the negative class. Also called misses.",
   fun = function(task, model, pred, feats, extra.args) {
     measureFN(pred$data$truth, pred$data$response, pred$task.desc$negative)
-  }
-)
+  })
 
 #' @export measureFN
 #' @rdname measures
@@ -973,8 +937,7 @@ tpr = makeMeasure(id = "tpr", minimize = FALSE, best = 1, worst = 0,
   note = "Percentage of correctly classified observations in the positive class. Also called hit rate or recall or sensitivity.",
   fun = function(task, model, pred, feats, extra.args) {
     measureTPR(pred$data$truth, pred$data$response, pred$task.desc$positive)
-  }
-)
+  })
 
 #' @export measureTPR
 #' @rdname measures
@@ -992,8 +955,7 @@ tnr = makeMeasure(id = "tnr", minimize = FALSE, best = 1, worst = 0,
   note = "Percentage of correctly classified observations in the negative class. Also called specificity.",
   fun = function(task, model, pred, feats, extra.args) {
     measureTNR(pred$data$truth, pred$data$response, pred$task.desc$negative)
-  }
-)
+  })
 
 #' @export measureTNR
 #' @rdname measures
@@ -1011,8 +973,7 @@ fpr = makeMeasure(id = "fpr", minimize = TRUE, best = 0, worst = 1,
   note = "Percentage of misclassified observations in the positive class. Also called false alarm rate or fall-out.",
   fun = function(task, model, pred, feats, extra.args) {
     measureFPR(pred$data$truth, pred$data$response, pred$task.desc$negative, pred$task.desc$positive)
-  }
-)
+  })
 
 #' @export measureFPR
 #' @rdname measures
@@ -1030,8 +991,7 @@ fnr = makeMeasure(id = "fnr", minimize = TRUE, best = 0, worst = 1,
   note = "Percentage of misclassified observations in the negative class.",
   fun = function(task, model, pred, feats, extra.args) {
     measureFNR(pred$data$truth, pred$data$response, pred$task.desc$negative, pred$task.desc$positive)
-  }
-)
+  })
 
 #' @export measureFNR
 #' @rdname measures
@@ -1052,10 +1012,9 @@ ppv = makeMeasure(id = "ppv", minimize = FALSE, best = 1, worst = 0,
       prob = getPredictionProbabilities(pred)
     } else {
       prob = NULL
-      }
+    }
     measurePPV(pred$data$truth, pred$data$response, pred$task.desc$positive, prob)
-  }
-)
+  })
 
 #' @export measurePPV
 #' @rdname measures
@@ -1085,8 +1044,7 @@ npv = makeMeasure(id = "npv", minimize = FALSE, best = 1, worst = 0,
   note = "Defined as: tn / (tn + fn).",
   fun = function(task, model, pred, feats, extra.args) {
     measureNPV(pred$data$truth, pred$data$response, pred$task.desc$negative)
-  }
-)
+  })
 
 #' @export measureNPV
 #' @rdname measures
@@ -1104,8 +1062,7 @@ fdr = makeMeasure(id = "fdr", minimize = TRUE, best = 0, worst = 1,
   note = "Defined as: fp / (tp + fp).",
   fun = function(task, model, pred, feats, extra.args) {
     measureFDR(pred$data$truth, pred$data$response, pred$task.desc$positive)
-  }
-)
+  })
 
 #' @export measureFDR
 #' @rdname measures
@@ -1123,13 +1080,13 @@ mcc = makeMeasure(id = "mcc", minimize = FALSE,
   note = "Defined as (tp * tn - fp * fn) / sqrt((tp + fp) * (tp + fn) * (tn + fp) * (tn + fn)), denominator set to 1 if 0",
   fun = function(task, model, pred, feats, extra.args) {
     measureMCC(pred$data$truth, pred$data$response, pred$task.desc$negative, pred$task.desc$positive)
-  }
-)
+  })
 
 #' @export measureMCC
 #' @rdname measures
 #' @format none
 measureMCC = function(truth, response, negative, positive) {
+
   tn = as.numeric(measureTN(truth, response, negative))
   tp = as.numeric(measureTP(truth, response, positive))
   fn = as.numeric(measureFN(truth, response, negative))
@@ -1151,8 +1108,7 @@ f1 = makeMeasure(id = "f1", minimize = FALSE, best = 1, worst = 0,
   note = "Defined as: 2 * tp/ (sum(truth == positive) + sum(response == positive))",
   fun = function(task, model, pred, feats, extra.args) {
     measureF1(pred$data$truth, pred$data$response, pred$task.desc$positive)
-  }
-)
+  })
 
 #' @export measureF1
 #' @rdname measures
@@ -1171,8 +1127,7 @@ gmean = makeMeasure(id = "gmean", minimize = FALSE, best = 1, worst = 0,
   note = "Geometric mean of recall and specificity.",
   fun = function(task, model, pred, feats, extra.args) {
     measureGMEAN(pred$data$truth, pred$data$response, pred$task.desc$negative, pred$task.desc$positive)
-  }
-)
+  })
 
 #' @export measureGMEAN
 #' @rdname measures
@@ -1194,8 +1149,7 @@ gpr = makeMeasure(id = "gpr", minimize = FALSE, best = 1, worst = 0,
   note = "Defined as: sqrt(ppv * tpr)",
   fun = function(task, model, pred, feats, extra.args) {
     measureGPR(pred$data$truth, pred$data$response, pred$task.desc$positive)
-  }
-)
+  })
 
 #' @export measureGPR
 #' @rdname measures
@@ -1218,7 +1172,7 @@ multilabel.hamloss = makeMeasure(id = "multilabel.hamloss", minimize = TRUE, bes
   fun = function(task, model, pred, feats, extra.args) {
     measureMultilabelHamloss(getPredictionTruth.PredictionMultilabel(pred),
       getPredictionResponse.PredictionMultilabel(pred))
-})
+  })
 
 #' @export measureMultilabelHamloss
 #' @rdname measures
@@ -1237,9 +1191,8 @@ multilabel.subset01 = makeMeasure(id = "multilabel.subset01", minimize = TRUE, b
   following the definition by Charte and Charte: https://journal.r-project.org/archive/2015-2/charte-charte.pdf.",
   fun = function(task, model, pred, feats, extra.args) {
     measureMultilabelSubset01(getPredictionTruth.PredictionMultilabel(pred),
-    getPredictionResponse.PredictionMultilabel(pred))
-  }
-)
+      getPredictionResponse.PredictionMultilabel(pred))
+  })
 
 #' @export measureMultilabelSubset01
 #' @rdname measures
@@ -1259,9 +1212,8 @@ multilabel.f1 = makeMeasure(id = "multilabel.f1", minimize = FALSE, best = 1, wo
   Fractions where the denominator becomes 0 are replaced with 1 before computing the average across all instances.",
   fun = function(task, model, pred, feats, extra.args) {
     measureMultilabelF1(getPredictionTruth.PredictionMultilabel(pred),
-    getPredictionResponse.PredictionMultilabel(pred))
-  }
-)
+      getPredictionResponse.PredictionMultilabel(pred))
+  })
 
 #' @export measureMultilabelF1
 #' @rdname measures
@@ -1283,9 +1235,8 @@ multilabel.acc = makeMeasure(id = "multilabel.acc", minimize = FALSE, best = 1,
   Fractions where the denominator becomes 0 are replaced with 1 before computing the average across all instances.",
   fun = function(task, model, pred, feats, extra.args) {
     measureMultilabelACC(getPredictionTruth.PredictionMultilabel(pred),
-    getPredictionResponse.PredictionMultilabel(pred))
-  }
-)
+      getPredictionResponse.PredictionMultilabel(pred))
+  })
 
 #' @export measureMultilabelACC
 #' @rdname measures
@@ -1307,9 +1258,8 @@ multilabel.ppv = makeMeasure(id = "multilabel.ppv", minimize = FALSE, best = 1,
   Fractions where the denominator becomes 0 are ignored in the average calculation.",
   fun = function(task, model, pred, feats, extra.args) {
     measureMultilabelPPV(getPredictionTruth.PredictionMultilabel(pred),
-    getPredictionResponse.PredictionMultilabel(pred))
-  }
-)
+      getPredictionResponse.PredictionMultilabel(pred))
+  })
 
 #' @export measureMultilabelPPV
 #' @rdname measures
@@ -1331,9 +1281,8 @@ multilabel.tpr = makeMeasure(id = "multilabel.tpr", minimize = FALSE, best = 1,
   Fractions where the denominator becomes 0 are ignored in the average calculation.",
   fun = function(task, model, pred, feats, extra.args) {
     measureMultilabelTPR(getPredictionTruth.PredictionMultilabel(pred),
-    getPredictionResponse.PredictionMultilabel(pred))
-  }
-)
+      getPredictionResponse.PredictionMultilabel(pred))
+  })
 
 #' @export measureMultilabelTPR
 #' @rdname measures
@@ -1357,12 +1306,12 @@ cindex = makeMeasure(id = "cindex", minimize = FALSE, best = 1, worst = 0,
   fun = function(task, model, pred, feats, extra.args) {
     requirePackages("_Hmisc")
     y = getPredictionResponse(pred)
-    if (anyMissing(y))
+    if (anyMissing(y)) {
       return(NA_real_)
+    }
     s = getPredictionTruth(pred)
     Hmisc::rcorr.cens(-1 * y, s)[["C Index"]]
-  }
-)
+  })
 
 #' @export cindex.uno
 #' @rdname measures
@@ -1378,8 +1327,9 @@ cindex.uno = makeMeasure(id = "cindex.uno", minimize = FALSE, best = 1, worst =
   fun = function(task, model, pred, feats, extra.args) {
     requirePackages("_survAUC")
     y = getPredictionResponse(pred)
-    if (anyMissing(y))
+    if (anyMissing(y)) {
       return(NA_real_)
+    }
     surv.train = getTaskTargets(task, recode.target = "surv")[model$subset]
     max.time = assertNumber(extra.args$max.time, null.ok = TRUE) %??% max(getTaskTargets(task)[, 1L])
     survAUC::UnoC(Surv.rsp = surv.train, Surv.rsp.new = getPredictionTruth(pred), time = max.time, lpnew = y)
@@ -1393,7 +1343,7 @@ cindex.uno = makeMeasure(id = "cindex.uno", minimize = FALSE, best = 1, worst =
 #' @references
 #' H. Uno et al.
 #' *Evaluating Prediction Rules for T-Year Survivors with Censored Regression Models*
-#' Journal of the American Statistical Association 102, no. 478 (2007): 527-37. <http://www.jstor.org/stable/27639883>.
+#' Journal of the American Statistical Association 102, no. 478 (2007): 527-37. <https://www.jstor.org/stable/27639883>.
 iauc.uno = makeMeasure(id = "iauc.uno", minimize = FALSE, best = 1, worst = 0,
   properties = c("surv", "req.pred", "req.truth", "req.model", "req.task"),
   name = "Uno's estimator of cumulative AUC for right censored time-to-event data",
@@ -1404,8 +1354,9 @@ iauc.uno = makeMeasure(id = "iauc.uno", minimize = FALSE, best = 1, worst = 0,
     times = seq(from = 0, to = max.time, length.out = extra.args$resolution)
     surv.train = getTaskTargets(task, recode.target = "surv")[model$subset]
     y = getPredictionResponse(pred)
-    if (anyMissing(y))
+    if (anyMissing(y)) {
       return(NA_real_)
+    }
     survAUC::AUC.uno(Surv.rsp = surv.train, Surv.rsp.new = getPredictionTruth(pred), times = times, lpnew = y)$iauc
   },
   extra.args = list(max.time = NULL, resolution = 1000L)
@@ -1419,6 +1370,7 @@ ibrier = makeMeasure(id = "ibrier", minimize = TRUE, best = 0, worst = 1,
   name = "Integrated brier score using Kaplan-Meier estimator for weighting",
   note = "Only works for methods for which probabilities are provided via pec::predictSurvProb. Currently these are only coxph and randomForestSRC. To set an upper time limit, set argument max.time (defaults to max time in test data). Implemented in pec::pec",
   fun = function(task, model, pred, feats, extra.args) {
+
     requirePackages(c("survival", "pec"))
     targets = getTaskTargets(task)
     tn = getTaskTargetNames(task)
@@ -1430,7 +1382,7 @@ ibrier = makeMeasure(id = "ibrier", minimize = TRUE, best = 0, worst = 1,
     probs = predictSurvProb(getLearnerModel(model, more.unwrap = TRUE), newdata = newdata, times = grid)
     perror = pec(probs, f, data = newdata[, tn], times = grid, exact = FALSE, exactness = 99L,
       maxtime = max.time, verbose = FALSE, reference = FALSE)
-    
+
 
     # FIXME: this might be the wrong number!
     crps(perror, times = max.time)[1L, ]
@@ -1455,8 +1407,7 @@ meancosts = makeMeasure(id = "meancosts", minimize = TRUE, best = 0, worst = Inf
       costs[id, cl]
     }, ids, classes, SIMPLIFY = TRUE, USE.NAMES = FALSE)
     mean(y)
-  }
-)
+  })
 
 #' @export mcp
 #' @rdname measures
@@ -1468,8 +1419,7 @@ mcp = makeMeasure(id = "mcp", minimize = TRUE, best = 0, worst = Inf,
     mc = meancosts$fun(task, NULL, pred, NULL, extra.args)
     oc = mean(apply(getTaskCosts(task), 1L, min))
     mc - oc
-  }
-)
+  })
 
 ###############################################################################
 ### clustering ###
@@ -1489,8 +1439,7 @@ db = makeMeasure(id = "db", minimize = TRUE, best = 0, worst = Inf,
     } else {
       NA
     }
-  }
-)
+  })
 
 #' @export dunn
 #' @rdname measures
@@ -1504,13 +1453,12 @@ dunn = makeMeasure(id = "dunn", minimize = FALSE, best = Inf, worst = 0,
     suppressMessages(requirePackages("clValid", default.method = "load"))
     r = as.integer(as.factor(pred$data$response))
     clValid::dunn(Data = feats, clusters = r)
-  }
-)
+  })
 
 #' @export G1
 #' @rdname measures
 #' @format none
-G1 = makeMeasure(id = "G1", minimize = FALSE, best = Inf, worst = 0,  # nolint
+G1 = makeMeasure(id = "G1", minimize = FALSE, best = Inf, worst = 0, # nolint
   properties = c("cluster", "req.pred", "req.feats"),
   name = "Calinski-Harabasz pseudo F statistic",
   note = "Defined as ratio of between-cluster variance to within cluster variance. See `?clusterSim::index.G1`.",
@@ -1518,13 +1466,12 @@ G1 = makeMeasure(id = "G1", minimize = FALSE, best = Inf, worst = 0,  # nolint
     requirePackages("clusterSim", default.method = "load")
     r = as.integer(as.factor(pred$data$response))
     clusterSim::index.G1(feats, r)
-  }
-)
+  })
 
 #' @export G2
 #' @rdname measures
 #' @format none
-G2 = makeMeasure(id = "G2", minimize = FALSE, best = 1, worst = 0,  # nolint
+G2 = makeMeasure(id = "G2", minimize = FALSE, best = 1, worst = 0, # nolint
   properties = c("cluster", "req.pred", "req.feats"),
   name = "Baker and Hubert adaptation of Goodman-Kruskal's gamma statistic",
   note = "Defined as: (number of concordant comparisons - number of discordant comparisons) / (number of concordant comparisons + number of discordant comparisons). See `?clusterSim::index.G2`.",
@@ -1532,8 +1479,7 @@ G2 = makeMeasure(id = "G2", minimize = FALSE, best = 1, worst = 0,  # nolint
     requirePackages("clusterSim", default.method = "load")
     r = as.integer(as.factor(pred$data$response))
     clusterSim::index.G2(clusterSim::dist.GDM(feats), r)
-  }
-)
+  })
 
 #' @export silhouette
 #' @rdname measures
@@ -1546,5 +1492,4 @@ silhouette = makeMeasure(id = "silhouette", minimize = FALSE, best = Inf, worst
     requirePackages("clusterSim", default.method = "load")
     r = as.integer(as.factor(pred$data$response))
     clusterSim::index.S(clusterSim::dist.GDM(feats), r)
-  }
-)
+  })
