@@ -1,4 +1,5 @@
 tuneGenSA = function(learner, task, resampling, measures, par.set, control, opt.path, show.info, resample.fun) {
+
   requirePackages("GenSA", why = "tuneGenSA", default.method = "load")
 
   low = getLower(par.set)
@@ -15,9 +16,10 @@ tuneGenSA = function(learner, task, resampling, measures, par.set, control, opt.
 
   # FIXME: the following condition can be removed, once we are able to fix the
   # budget in GenSA
-  if (!is.null(control$budget) && res$counts > control$budget)
+  if (!is.null(control$budget) && res$counts > control$budget) {
     warningf("GenSA used %i function calls, exceededing the given budget of %i evaluations.",
       res$counts, control$budget)
+  }
 
   makeTuneResultFromOptPath(learner, par.set, measures, resampling, control, opt.path)
 }
