@@ -6,9 +6,9 @@ test_that("getHyperPars", {
   expect_equal(getHyperPars(lrn), list(xval = 0))
 
   lrn = makeLearner("classif.lda")
-  named_list = list()
-  names(named_list) = character(0)
-  expect_equal(getHyperPars(lrn), named_list)
+  named.list = list()
+  names(named.list) = character(0)
+  expect_equal(getHyperPars(lrn), named.list)
 
   lrn = makeFilterWrapper(makeLearner("classif.rpart"))
   expect_true(setequal(names(getHyperPars(lrn)), c("xval", "fw.method")))
@@ -22,7 +22,7 @@ test_that("getHyperPars", {
   lrn = makeMultilabelBinaryRelevanceWrapper("classif.rpart")
   expect_true(setequal(getHyperPars(lrn), list(xval = 0)))
 
-  #Missing values should not be omitted and printed
+  # Missing values should not be omitted and printed
   lrn = makeLearner("classif.xgboost", missing = NA)
   expect_output(print(lrn), "missing=NA")
   lrn = makeLearner("regr.xgboost", missing = NA)
