@@ -48,11 +48,11 @@ test_that("resample", {
   f2 = factor(rep(td$negative, cv.i$size), levels = td$class.levels)
   expect_equal(rf4$data$response, f2)
 
-  ct = makeClassifTask(data = iris[,c("Species", "Petal.Width")], target = "Species")
+  ct = makeClassifTask(data = iris[, c("Species", "Petal.Width")], target = "Species")
   fit = resample(lrn1, ct, makeResampleDesc("CV", iters = 2))
 
   expect_error(resample("classif.rpart", multiclass.task, makeResampleDesc("Holdout"),
-      measures = list()), "length >= 1")
+    measures = list()), "length >= 1")
 })
 
 test_that("resampling, predicting train set works", {
@@ -69,7 +69,7 @@ test_that("resampling, predicting train set works", {
   expect_false(is.null(r$pred$predict.type))
   expect_false(is.null(r$pred$threshold))
   expect_equal(getTaskDesc(multiclass.task), r$pred$task.desc)
-  
+
   rdesc = makeResampleDesc("CV", iters = 2, predict = "both")
   lrn = makeLearner("classif.rpart")
   m1 = setAggregation(mmce, train.mean)
@@ -81,9 +81,6 @@ test_that("resampling, predicting train set works", {
   expect_false(is.null(r$pred$predict.type))
   expect_false(is.null(r$pred$threshold))
   expect_equal(getTaskDesc(multiclass.task), r$pred$task.desc)
-  
-  
-
 })
 
 
@@ -136,7 +133,7 @@ test_that("resample has error messages when prediction fails", {
   configureMlr(on.learner.warning = "quiet")
 
   lrn = makeLearner("classif.knn")
-  lrn$properties = c(lrn$properties, c("missings"))
+  lrn$properties = c(lrn$properties, "missings")
 
   task = makeClassifTask("test", data = Sonar, target = "Class")
   task$env$data$V1[1:2] = NA
@@ -162,7 +159,7 @@ test_that("resample is extended by an additional measure", {
       measures = list(mmce, ber, auc, brier)
       # set aggregation method
       measures = lapply(measures, setAggregation, a)
-      #if (p == "train") measures = lapply(measures, setAggregation, train.mean)
+      # if (p == "train") measures = lapply(measures, setAggregation, train.mean)
       # create ResampleResult with all measures
       res.all = resample(lrn, binaryclass.task, rdesc, measures)
       # create ResampleResult with one measure and add the other ones afterwards
@@ -180,3 +177,36 @@ test_that("resample is extended by an additional measure", {
   res = resample(lrn, binaryclass.task, cv3, mmce, keep.pred = FALSE)
   expect_error(addRRMeasure(res, auc), "keep.pred")
 })
+
+test_that("resample printer respects show.info", {
+  show.info.saved = getMlrOptions()$show.info
+  lrn = makeLearner("regr.lm")
+
+  configureMlr(show.info = TRUE)
+  expect_message(resample(lrn, bh.task, cv10, list(mape, medae, mse)))
+
+  configureMlr(show.info = FALSE)
+  expect_silent(resample(lrn, bh.task, cv10, list(mape, medae, mse)))
+
+  configureMlr(show.info = show.info.saved)
+})
+
+test_that("resample drops unseen factors in predict data set", {
+  data = data.frame(a = c("a", "b", "a", "b", "a", "c"),
+    b = c(1, 1, 2, 2, 2, 1),
+    trg = c("a", "b", "a", "b", "a", "b"))
+  task = makeClassifTask("unseen.factors", data, "trg")
+  resinst = makeResampleInstance("Holdout", task)
+  resinst$train.inds[[1]] = 1:4
+  resinst$test.inds[[1]] = 5:6
+
+  lrn = makeLearner("classif.logreg", fix.factors.prediction = FALSE)
+  model = train(lrn, subsetTask(task, 1:4))
+  expect_error(predict(model, subsetTask(task, 5:6)), "factor a has new levels c")
+  expect_error(resample(lrn, task, resinst), "factor a has new levels c")
+
+  lrn = makeLearner("classif.logreg", fix.factors.prediction = TRUE)
+  model = train(lrn, subsetTask(task, 1:4))
+  predict(model, subsetTask(task, 5:6))
+  resample(lrn, task, resinst)
+})
