@@ -5,14 +5,14 @@ test_that("classif_rotationForest", {
 
   parset.list = list(
     list(),
-    list(L = 5L,  K = 2L),
+    list(L = 5L, K = 2L),
     list(L = 10L, K = 2L)
   )
 
   old.predicts.list = list()
   old.probs.list = list()
 
-  for (i in 1:length(parset.list)) {
+  for (i in seq_along(parset.list)) {
     parset = parset.list[[i]]
     train = binaryclass.train
     target = train[, binaryclass.target]
