@@ -15,7 +15,7 @@ test_that("regr_LiblineaRL2L1SVR", {
   old.predicts.list = list()
   old.probs.list = list()
 
-  for (i in 1L:length(parset.list)) {
+  for (i in seq_along(parset.list)) {
     parset = parset.list[[i]]
     pars = list(data = regr.num.train[, -regr.num.class.col],
       target = regr.num.train[, regr.num.target], type = 13L)
